@@ -89,14 +89,12 @@ enum {
 
 static guint gsp_app_signals[LAST_SIGNAL] = { 0 };
 
-
 G_DEFINE_TYPE_WITH_PRIVATE (GspApp, gsp_app, G_TYPE_OBJECT)
 
 static void     gsp_app_dispose  (GObject *object);
 static void     gsp_app_finalize (GObject *object);
 static gboolean _gsp_app_save    (gpointer data);
 
-
 static gboolean
 _gsp_str_equal (const char *a,
                 const char *b)
@@ -116,7 +114,6 @@ _gsp_str_equal (const char *a,
         return FALSE;
 }
 
-
 static void
 gsp_app_class_init (GspAppClass *class)
 {
@@ -493,7 +490,7 @@ _gsp_app_save (gpointer data)
         }
 
         _gsp_ensure_user_autostart_dir ();
-        if (gsp_key_file_to_file (keyfile, priv->path, NULL)) {
+        if (g_key_file_save_to_file (keyfile, priv->path, NULL)) {
                 priv->skip_next_monitor_event = TRUE;
                 _gsp_app_save_done_success (app);
         } else {
