@@ -215,7 +215,6 @@ gsm_xsmp_client_init (GsmXSMPClient *client)
         priv->next_save_yourself_allow_interact = FALSE;
 }
 
-
 static void
 delete_property (GsmXSMPClient *client,
                  const char    *name)
@@ -248,7 +247,6 @@ delete_property (GsmXSMPClient *client,
         SmFreeProperty (prop);
 }
 
-
 static void
 debug_print_property (SmProp *prop)
 {
@@ -280,7 +278,6 @@ debug_print_property (SmProp *prop)
         }
 }
 
-
 static void
 set_properties_callback (SmsConn     conn,
                          SmPointer   manager_data,
@@ -442,7 +439,7 @@ do_save_yourself (GsmXSMPClient *client,
                 g_debug ("GsmXSMPClient:   queuing new SaveYourself for '%s'",
                          priv->description);
                 priv->next_save_yourself = save_type;
-                priv->next_save_yourself_allow_interact = allow_interact;
+                priv->next_save_yourself_allow_interact = (allow_interact != FALSE);
         } else {
                 priv->current_save_yourself = save_type;
                 /* make sure we don't have anything queued */
@@ -1106,7 +1103,6 @@ register_client_callback (SmsConn    conn,
                  priv->description,
                  previous_id ? previous_id : "NULL");
 
-
         /* There are three cases:
          * 1. id is NULL - we'll use a new one
          * 2. id is known - we'll use known one
@@ -1153,7 +1149,6 @@ register_client_callback (SmsConn    conn,
         return TRUE;
 }
 
-
 static void
 save_yourself_request_callback (SmsConn   conn,
                                 SmPointer manager_data,
